; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = "some_name"
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /F, a    ;hold fwd while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;               command = ~30
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their engine.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands are given below. Delete, add, or modify as you wish.

;-| Super Motions |--------------------------------------------------------

[Command]
name = "kiattack"
command = ~B, DB, D, DF, F, x
time = 60

[Command]
name = "powerup"
command = D, DF, F, D, DF, F, y
time = 30

[Command]
name = "kamehame"
command = D, DB, B, F, x
time = 30

;-| Special Motions |------------------------------------------------------

[Command]
name = "kiswordcombo"
command = D, DF, F, b
time = 30

[Command]
name = "abise"
command = D, DB, B, b
time = 30

[Command]
name = "vegettocombo"
command = F, FD, D, DB, B, b
time = 45

[Command]
name = "bombdash"
command = F, FD, D, DB, B, a
time = 45

[Command]
name = "geki"
command = B, DB, D, DF, F, b
time = 45

[Command]
name = "tripla"
command = D, DF, F, a
time = 30

[Command]
name = "kisword"
command = F, D, F, y
time = 30

[Command]
name = "X_launcher"
command = D, F, x
time = 30

[Command]
name = "X_finisher"
command = D, B, x
time = 30

[Command]
name = "X_forte"
command = F, B, F, x
time = 30

[Command]
name = "dashelbow"
command = F, F, a
time = 30

[Command]
name = "sunkaa"
command = B, B, a
time = 30

[Command]
name = "sunkab"
command = B, B, b
time = 30

[Command]
name = "dantsu"
command = F, F, y
time = 30

[Command]
name = "flyingkick"
command = F, B, F, b
time = 30

[Command]
name = "slash"
command = F, DF, D, b
time = 30

[Command]
name = "Goku"
command = D, DF, F, z
time = 30

[Command]
name = "Vegita"
command = D, DB, B, z 
time = 30

[Command]
name = "Gotenks"
command = F, B, F, z 
time = 30

[Command]
name = "Gohan"
command = B, F, B, z 
time = 30

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF";Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB";Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = a+b
time = 1

[Command]
name = "ab"
command = a+b
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "fwd_a"
command = /F,a
time = 1

[Command]
name = "hellshoot"
command = /F,b
time = 1

[Command]
name = "fwd_c"
command = /F,c
time = 1

[Command]
name = "fwd_x"
command = /F,x
time = 1

[Command]
name = "fwd_y"
command = /F,y
time = 1

[Command]
name = "fwd_z"
command = /F,z
time = 1

[Command]
name = "back_a"
command = /B,a
time = 1

[Command]
name = "back_b"
command = /B,b
time = 1

[Command]
name = "kibarrier"
command = /B,x
time = 1

[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

[Command]
name = "holdx"
command = /x
time = 1

[Command]
name = "holdy"
command = /y
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "va"
command = a
time = 1

[Command]
name = "vb"
command = b
time = 1

[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup";Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1


;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1]                  ;Don't change this
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = "command_name"
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.  
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in. 


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;RunFwd
[State -1]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;RunBack
[State -1]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl = 1

;===========================================================================
;---------------------------------------------------------------------------
; Kamehameha (Vegetto)
[State -1]
type = ChangeState
value = 3100
triggerall = Var(7) < 1
triggerall = command = "kamehame"
triggerall = power >= 1000
trigger1 = statetype != A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; Final Flash
[State -1]
type = ChangeState
value = 23000
triggerall = Var(7) = 2
triggerall = command = "kamehame"
triggerall = power >= 2000
trigger1 = statetype != A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; Kamehameha (Vegetto)
[State -1]
type = ChangeState
value = 13000
triggerall = Var(7) = 1
triggerall = command = "kamehame"
triggerall = power >= 2000
trigger1 = statetype != A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; KI Attack
[State -1]
type = ChangeState
value = 23100
triggerall = Var(7) = 2
triggerall = command = "powerup"
triggerall = power >= 1000
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; KI Attack (no ar)
;[State -1]
;type = ChangeState
;value = 23110
;triggerall = Var(7) = 2
;triggerall = command = "kiattack"
;triggerall = power >= 1000
;trigger1 = statetype = A
;trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; KI Sword
[State -1]
type = ChangeState
value = 1500
triggerall = Var(7) < 1
triggerall = command = "kisword"
trigger1 = statetype != A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Vegetto Combo
[State -1]
type = ChangeState
value = 1400
triggerall = Var(7) < 1
triggerall = command = "vegettocombo"
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1

;---------------------------------------------------------------------------
; Super Dash
[State -1]
type = ChangeState
value = 21100
triggerall = Var(7) = 2
triggerall = command = "kiswordcombo"
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1

;---------------------------------------------------------------------------
; Bomb Dash
[State -1]
type = ChangeState
value = 21300
triggerall = Var(7) = 2
triggerall = command = "bombdash"
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1

;---------------------------------------------------------------------------
; Sunkanidou (a)
[State -1]
type = ChangeState
value = 11500
triggerall = Var(7) = 1
triggerall = command = "sunkaa"
trigger1 = statetype != A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; Sunkanidou (b)
[State -1]
type = ChangeState
value = 11510
triggerall = Var(7) = 1
triggerall = command = "sunkab"
trigger1 = statetype != A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; Abiseregi
[State -1]
type = ChangeState
value = 11400
triggerall = Var(7) = 1
triggerall = command = "abise"
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1

;---------------------------------------------------------------------------
; Flying Kicks
[State -1]
type = ChangeState
value = 1300
triggerall = Var(7) < 1
triggerall = command = "flyingkick"
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
;---------------------------------------------------------------------------

; Jump Knee Lift
[State -1]
type = ChangeState
value = 11000
triggerall = Var(7) = 1
triggerall = command = "flyingkick"
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
;---------------------------------------------------------------------------

;Dash Elbow
[State -1]
type = ChangeState
value = 1200
triggerall = Var(7) < 1
triggerall = command = "dashelbow"
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1

;---------------------------------------------------------------------------
; Gekiretsurenkyaku
[State -1]
type = ChangeState
value = 11300
triggerall = Var(7) = 1
triggerall = command = "geki"
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1

;---------------------------------------------------------------------------
; Dantsu Energy Dan
[State -1]
type = ChangeState
value = 11200
triggerall = Var(7) = 1
triggerall = command = "dantsu"
triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Triple Fireball
[State -1]
type = ChangeState
value = 1100
triggerall = Var(7) = 0
triggerall = command = "tripla"
triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; Renzoku Energy Dan
[State -1]
type = ChangeState
value = 21200
triggerall = Var(7) = 2
triggerall = command = "tripla"
triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; Air Renzoku Energy Dan
[State -1]
type = ChangeState
value = 21210
triggerall = Var(7) = 2
triggerall = command = "tripla"
triggerall = numproj = 0
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; Double Slash Down Kick
[State -1]
type = ChangeState
value = 615
triggerall = Var(7) < 1
triggerall = command = "slash"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; X launcher
[State -1]
type = ChangeState
value = 701
triggerall = Var(7) < 1
triggerall = command = "X_launcher"
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 210
trigger2 = movecontact = 1
trigger3 = stateno = 400
trigger3 = movecontact = 1
trigger4 = stateno = 410
trigger4 = movecontact = 1
trigger5 = stateno = 200
trigger5 = movecontact = 1

;X finisher
[State -1]
type = ChangeState
value = 702
triggerall = command = "X_finisher"
triggerall = Var(7) < 1
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1

;X air finisher
[State -1]
type = ChangeState
value = 704
triggerall = Var(7) < 1
triggerall = command = "X_finisher"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 600
trigger2 = movecontact = 1
trigger3 = stateno = 610
trigger3 = movecontact = 1

;X forte
[State -1]
type = ChangeState
value = 703
triggerall = Var(7) < 1
triggerall = command = "X_forte"
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1

;---------------------------------------------------------------------------
; Strikers
; Gotenks
[State -1]
type = ChangeState
value = 5998
triggerall = command = "Gotenks"
triggerall = numhelper < 1
triggerall = p2name != "Gotenks"
triggerall = p3name != "Gotenks"
triggerall = p4name != "Gotenks"
trigger1 = statetype != A
trigger1 = ctrl = 1

; Mystic Gohan
[State -1]
type = ChangeState
value = 6199
triggerall = command = "Gohan"
triggerall = numhelper < 1
triggerall = p2name != "Gohan"
triggerall = p3name != "Gohan"
triggerall = p4name != "Gohan"
trigger1 = statetype != A
trigger1 = ctrl = 1

;===========================================================================
;---------------------------------------------------------------------------
; Desfusaionar
; Goku
[State -1]
type = ChangeState
value = 9999
triggerall = command = "Goku"
triggerall = p1name != "Goku"
triggerall = p2name != "Goku"
triggerall = p3name != "Goku"
triggerall = p4name != "Goku"
triggerall = P1Name != "Goku SSJ4 by _Vision and MRP"
triggerall = P2Name != "Goku SSJ4 by _Vision and MRP"
triggerall = p3name != "Goku SSJ4 by _Vision and MRP"
triggerall = p4name != "Goku SSJ4 by _Vision and MRP"
triggerall = Var(7) = 0
triggerall = Life <= 200
trigger1 = statetype != A
trigger1 = ctrl = 1

;Vegita
[State -1]
type = ChangeState
value = 19999
triggerall = command = "Vegita"
triggerall = P2Name != "Vegita"
triggerall = P2Name != "Vegeta Normal 2 by EB"
triggerall = P2Name != "Vegeta Normal by OverMind"
triggerall = P2Name != "Vegeta Super Sayjin 4 by EB and BS"
triggerall = P2Name != "Shadow Vegeta"
triggerall = P2Name != "Super Vegeta"
triggerall = P3Name != "Vegita"
triggerall = P3Name != "Vegeta Normal 2 by EB"
triggerall = P3Name != "Vegeta Normal by OverMind"
triggerall = P3Name != "Vegeta Super Sayjin 4 by EB and BS"
triggerall = P3Name != "Shadow Vegeta"
triggerall = P3Name != "Super Vegeta"
triggerall = P4Name != "Vegita"
triggerall = P4Name != "Vegeta Normal 2 by EB"
triggerall = P4Name != "Vegeta Normal by OverMind"
triggerall = P4Name != "Vegeta Super Sayjin 4 by EB and BS"
triggerall = P4Name != "Shadow Vegeta"
triggerall = P4Name != "Super Vegeta"
triggerall = Var(7) = 0
triggerall = Life <= 200
trigger1 = statetype != A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; Trocar
; Vegita -> Goku
[State -1]
type = ChangeState
value = 9997
triggerall = command = "Goku"
triggerall = p1name != "Goku"
triggerall = p2name != "Goku"
triggerall = p3name != "Goku"
triggerall = p4name != "Goku"
triggerall = P1Name != "Goku SSJ4 by _Vision and MRP"
triggerall = P2Name != "Goku SSJ4 by _Vision and MRP"
triggerall = p3name != "Goku SSJ4 by _Vision and MRP"
triggerall = p4name != "Goku SSJ4 by _Vision and MRP"
triggerall = Var(7) = 2
triggerall = NumHelper(19997) = 0
trigger1 = statetype != A
trigger1 = ctrl = 1

; Goku -> Vegita
[State -1]
type = ChangeState
value = 19997
triggerall = command = "Vegita"
triggerall = P2Name != "Vegita"
triggerall = P2Name != "Vegeta Normal 2 by EB"
triggerall = P2Name != "Vegeta Normal by OverMind"
triggerall = P2Name != "Vegeta Super Sayjin 4 by EB and BS"
triggerall = P2Name != "Shadow Vegeta"
triggerall = P2Name != "Super Vegeta"
triggerall = P3Name != "Vegita"
triggerall = P3Name != "Vegeta Normal 2 by EB"
triggerall = P3Name != "Vegeta Normal by OverMind"
triggerall = P3Name != "Vegeta Super Sayjin 4 by EB and BS"
triggerall = P3Name != "Shadow Vegeta"
triggerall = P3Name != "Super Vegeta"
triggerall = P4Name != "Vegita"
triggerall = P4Name != "Vegeta Normal 2 by EB"
triggerall = P4Name != "Vegeta Normal by OverMind"
triggerall = P4Name != "Vegeta Super Sayjin 4 by EB and BS"
triggerall = P4Name != "Shadow Vegeta"
triggerall = P4Name != "Super Vegeta"
triggerall = Var(7) = 1
triggerall = NumHelper(9997) = 0
trigger1 = statetype != A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; KI Barrier
[State -1]
type = ChangeState
value = 900
triggerall = Var(7) < 1
triggerall = command = "kibarrier"
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Heel Shoot
[State -1]
type = ChangeState
value = 215
triggerall = Var(7) < 1
triggerall = command = "hellshoot"
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------

;Voar (No Cho)
[State -1]
type = ChangeState
value = 2100
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger1 = command = "c"

;Voar
[State -1]
type = ChangeState
value = 2000
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger1 = Pos Y < 0
trigger1 = command = "c"

;---------------------------------------------------------------------------
; Carregar no cho
[State -1]
type = ChangeState
value = 735
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger1 = command = "holdx"
trigger1 = command = "holdy"

; Carregar no ar
[State -1]
type = ChangeState
value = 745
triggerall = command = "holdx"
triggerall = command = "holdy"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 2000

;---------------------------------------------------------------------------
;Soco parado
[State -1]
type = ChangeState
value = 199
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 2000

;---------------------------------------------------------------------------
;Chute parado
[State -1]
type = ChangeState
value = 209
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 2000
trigger3 = stateno = 200
trigger3 = movecontact = 1

;---------------------------------------------------------------------------
;X bsico
[State -1]
type = ChangeState
value = 700
triggerall = Var(7) < 1
triggerall = command = "x"
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 2000
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 200
trigger6 = movecontact = 1

;---------------------------------------------------------------------------
;Magia Simples
[State -1]
type = ChangeState
value = 1000
triggerall = Var(7) >= 0
triggerall = command = "y"
triggerall = NumProj = 0
trigger1 = statetype != A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Soco agachado
[State -1]
type = ChangeState
value = 400
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Chute agachado
[State -1]
type = ChangeState
value = 410
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 400
trigger2 = movecontact = 1

;---------------------------------------------------------------------------
;Soco no ar
[State -1]
type = ChangeState
value = 600
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Chute no ar
[State -1]
type = ChangeState
value = 610
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 600
trigger2 = movecontact = 1
